@@ -3,24 +3,18 @@ try:
 except ImportError:
     __version__ = "unknown"
 
-from ._channel_density import DensityWidget
-from ._channel_ROI import channel_ROI_widget
-from ._channel_space import channel_space_widget
-from ._contrast import contrast_widget
 from ._sample_data import (
     fetch_chroms_data,
     load_chroms_data_sample,
     make_rgb_cube_data,
 )
 from ._tooltip_pointer import tooltip_pointer_widget
+from ._widget import DiagnoseWidget
 
 __all__ = (
     "tooltip_pointer_widget",
     "make_rgb_cube_data",
     "fetch_chroms_data",
     "load_chroms_data_sample",
-    "contrast_widget",
-    "channel_space_widget",
-    "channel_ROI_widget",
-    "DensityWidget",
+    "DiagnoseWidget",
 )
